==> QLC%2B_4.12.6.tar.gz: qlcplus-QLC-_4.12.6/plugins/midi/src/MIDI_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation>MIDI Plugin konfigurieren</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation>MIDI-Kanal</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation>Initialisierungsnachricht</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="127"/>
        <source>Outputs</source>
        <translation>Ausgänge</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="150"/>
        <source>Inputs</source>
        <translation>Eingänge</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="214"/>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="139"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation>Dieses Plugin bietet Eingabe/Ausgabe Unterstützung für MIDI-Geräte.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="153"/>
        <source>No output support available.</source>
        <translation>Keine Ausgabe Unterstützung verfügbar.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="161"/>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="164"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Open</source>
        <translation>Geöffnet</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="274"/>
        <source>Not Open</source>
        <translation>Nicht geöffnet</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="167"/>
        <location filename="common/midiplugin.cpp" line="275"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="173"/>
        <source>Invalid Output</source>
        <translation>Falscher Ausgang</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="261"/>
        <source>No input support available.</source>
        <translation>Keine Eingangs Untestützung verfügbar.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="269"/>
        <source>Input</source>
        <translation>Eingang</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="281"/>
        <source>Invalid Input</source>
        <translation>Falscher Eingang</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="112"/>
        <source>No error occurred.</source>
        <translation>Es ist kein Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="114"/>
        <source>An error occurred when reading from the file.</source>
        <translation>Beim Lesen der Datei ist ein Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="116"/>
        <source>An error occurred when writing to the file.</source>
        <translation>Beim Schreiben der Datei ist ein Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="118"/>
        <source>A fatal error occurred.</source>
        <translation>Ein schwerwiegender Fehler ist aufgetreten.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="120"/>
        <source>Resource error occurred.</source>
        <translation>Ressourcen Fehler aufgetreten.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="122"/>
        <source>The file could not be opened.</source>
        <translation>Die Datei konnte nicht geöffnet werden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="124"/>
        <source>The operation was aborted.</source>
        <translation>Der Vorgang wurde abgebrochen.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="126"/>
        <source>A timeout occurred.</source>
        <translation>Es ist eine Zeitüberschreitung aufgetreten.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="128"/>
        <source>An unspecified error occurred.</source>
        <translation>Ein nicht spezifizierter Fehler ist aufgetreten.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="130"/>
        <source>The file could not be removed.</source>
        <translation>Die Datei konnte nicht entfernt werden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="132"/>
        <source>The file could not be renamed.</source>
        <translation>Die Datei konnte nicht umbenannt werden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="134"/>
        <source>The position in the file could not be changed.</source>
        <translation>Die Position innerhalb der Datei konnte nicht geändert werden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="136"/>
        <source>The file could not be resized.</source>
        <translation>Die Größenänderung der Datei konnte nicht durchgeführt werden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="138"/>
        <source>The file could not be accessed.</source>
        <translation>Zugriff auf die Datei nicht möglich.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="140"/>
        <source>The file could not be copied.</source>
        <translation>Datei konnte nicht kopiert werden.</translation>
    </message>
    <message>
        <location filename="../../../engine/src/qlcfile.cpp" line="142"/>
        <source>An unknown error occurred.</source>
        <translation>Ein unbekannter Fehler ist aufgetreten.</translation>
    </message>
</context>
</TS>

==> QLC%2B_4.14.0.tar.gz: qlcplus-QLC-_4.14.0/plugins/midi/src/MIDI_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigureMidiPlugin</name>
    <message>
        <location filename="common/configuremidiplugin.ui" line="33"/>
        <source>Configure MIDI Plugin</source>
        <translation>MIDI-Plugin konfigurieren</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="66"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="71"/>
        <source>MIDI Channel</source>
        <translation>MIDI-Kanal</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="76"/>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="81"/>
        <source>Init Message</source>
        <translation>Initialisierungsnachricht</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.ui" line="39"/>
        <source>Refresh</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="137"/>
        <source>Outputs</source>
        <translation>Ausgänge</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="160"/>
        <source>Inputs</source>
        <translation>Eingänge</translation>
    </message>
    <message>
        <location filename="common/configuremidiplugin.cpp" line="224"/>
        <source>None</source>
        <translation>Nichts</translation>
    </message>
</context>
<context>
    <name>MidiPlugin</name>
    <message>
        <location filename="common/midiplugin.cpp" line="138"/>
        <source>This plugin provides input/output support for MIDI devices.</source>
        <translation>Dieses Plugin bietet Eingabe/Ausgabe-Unterstützung für MIDI-Geräte.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="152"/>
        <source>No output support available.</source>
        <translation>Keine Ausgabeunterstützung verfügbar.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="160"/>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="163"/>
        <location filename="common/midiplugin.cpp" line="270"/>
        <source>Open</source>
        <translation>Geöffnet</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="165"/>
        <location filename="common/midiplugin.cpp" line="272"/>
        <source>Not Open</source>
        <translation>Nicht geöffnet</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="166"/>
        <location filename="common/midiplugin.cpp" line="273"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="172"/>
        <source>Invalid Output</source>
        <translation>Falscher Ausgang</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="259"/>
        <source>No input support available.</source>
        <translation>Keine Eingabeunterstützung verfügbar.</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="267"/>
        <source>Input</source>
        <translation>Eingang</translation>
    </message>
    <message>
        <location filename="common/midiplugin.cpp" line="279"/>
        <source>Invalid Input</source>
        <translation>Falscher Eingang</translation>
    </message>
</context>
</TS>
